@@ -21,6 +21,7 @@ from .._constants import (
     _PHOTOS_9_MODEL_VERSION,
     _PHOTOS_10_MODEL_VERSION,
     _PHOTOS_10B1_MODEL_VERSION,
+    _PHOTOS_11_MODEL_VERSION,
     _TESTED_DB_VERSIONS,
 )
 from ..sqlite_utils import sqlite_open_ro
@@ -147,6 +148,8 @@ def get_photos_version_from_model(db_file: str) -> int:
         return 9.9
     if _PHOTOS_10_MODEL_VERSION[0] <= model_ver <= _PHOTOS_10_MODEL_VERSION[1]:
         return 10
+    if _PHOTOS_11_MODEL_VERSION[0] <= model_ver <= _PHOTOS_11_MODEL_VERSION[1]:
+        return 11
     logger.warning(
         f"Unknown db / model version for {db_file}: model_ver={model_ver}; assuming latest version"
     )
